!function(e){var t={};function n(r){if(t[r])return t[r].exports;var l=t[r]={i:r,l:!1,exports:{}};return e[r].call(l.exports,l,l.exports,n),l.l=!0,l.exports}n.m=e,n.c=t,n.d=function(e,t,r){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:r})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var r=Object.create(null);if(n.r(r),Object.defineProperty(r,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var l in e)n.d(r,l,function(t){return e[t]}.bind(null,l));return r},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=0)}([function(e,t,n){e.exports=n(1)},function(e,t,n){(function(e){e.initUploadFields=function(e,t){var n=e.find("[name=csrfmiddlewaretoken]").val(),r=function(n){var r=function(e){return t&&t.prefix?"".concat(t.prefix,"-").concat(e):e}(n),l=e.find("[name=".concat(r,"]"));return l.length?l.val():(console.error("Cannot find input with name '".concat(r,"'")),null)},l=r("upload_url"),i=r("delete_url"),o=r("form_id");o&&l&&e.find(".file-uploader").each(function(e,r){var a=$(r),d=$(a.find("input[type=file]")),f=a.find(".file-uploader-container"),u=d.attr("name"),c=Boolean(d.attr("multiple")),p={element:f,fieldName:u,csrfToken:n,uploadUrl:l,deleteUrl:i,formId:o,multiple:c};t&&$.extend(p,t),c||$(f).on("complete",function(){$(a.find(".existing-files")).remove()}),function(e){var t=$(e.element),n={request:{endpoint:e.uploadUrl,params:{csrfmiddlewaretoken:e.csrfToken,field_name:e.fieldName,form_id:e.formId}},multiple:e.multiple,deleteFile:{enabled:!0,endpoint:e.deleteUrl,method:"POST",customHeaders:{"X-CSRFToken":e.csrfToken}},failedUploadTextDisplay:{maxChars:100,responseProperty:"error",enableTooltip:!0}};e.text&&(n.text=e.text),e.deleteFile&&$.extend(n.deleteFile,e.deleteFile),e.failedUploadTextDisplay&&$.extend(n.failedUploadTextDisplay,e.failedUploadTextDisplay),e.callbacks&&(n.callbacks=e.callbacks),e.template&&(n.template=e.template),e.validation&&(n.validation=e.validation),t.fineUploader(n);var r=t.data("files");r&&t.fineUploader("addInitialFiles",r.filter(function(e){return!e.existing}).map(function(e){return{uuid:e.id,name:e.name}}))}(p),d.remove()})}}).call(this,n(2))},function(e,t){var n;n=function(){return this}();try{n=n||new Function("return this")()}catch(e){"object"==typeof window&&(n=window)}e.exports=n}]);